# coding: utf-8

"""
Binance Staking REST API

OpenAPI Specification for the Binance Staking REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from binance_sdk_staking.rest_api.models.eth_staking_account_response_holdings import (
    EthStakingAccountResponseHoldings,
)
from binance_sdk_staking.rest_api.models.eth_staking_account_response_profit import (
    EthStakingAccountResponseProfit,
)
from typing import Set
from typing_extensions import Self


class EthStakingAccountResponse(BaseModel):
    """
    EthStakingAccountResponse
    """  # noqa: E501

    holding_in_eth: Optional[StrictStr] = Field(default=None, alias="holdingInETH")
    holdings: Optional[EthStakingAccountResponseHoldings] = None
    thirty_days_profit_in_eth: Optional[StrictStr] = Field(
        default=None, alias="thirtyDaysProfitInETH"
    )
    profit: Optional[EthStakingAccountResponseProfit] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "holdingInETH",
        "holdings",
        "thirtyDaysProfitInETH",
        "profit",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def is_array(cls) -> bool:
        return False

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EthStakingAccountResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set(
            [
                "additional_properties",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of holdings
        if self.holdings:
            _dict["holdings"] = self.holdings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of profit
        if self.profit:
            _dict["profit"] = self.profit.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EthStakingAccountResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "holdingInETH": obj.get("holdingInETH"),
                "holdings": (
                    EthStakingAccountResponseHoldings.from_dict(obj["holdings"])
                    if obj.get("holdings") is not None
                    else None
                ),
                "thirtyDaysProfitInETH": obj.get("thirtyDaysProfitInETH"),
                "profit": (
                    EthStakingAccountResponseProfit.from_dict(obj["profit"])
                    if obj.get("profit") is not None
                    else None
                ),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj
